==> linshare-core-1.8.8-src.tar.bz2: src/main/java/org/linagora/linshare/core/facade/webservice/user/impl/FunctionalityFacadeImpl.java <==
/*
 * LinShare is an open source filesharing software, part of the LinPKI software
 * suite, developed by Linagora.
 * 
 * Copyright (C) 2015 LINAGORA
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version, provided you comply with the Additional Terms applicable for
 * LinShare software by Linagora pursuant to Section 7 of the GNU Affero General
 * Public License, subsections (b), (c), and (e), pursuant to which you must
 * notably (i) retain the display of the “LinShare™” trademark/logo at the top
 * of the interface window, the display of the “You are using the Open Source
 * and free version of LinShare™, powered by Linagora © 2009–2015. Contribute to
 * Linshare R&D by subscribing to an Enterprise offer!” infobox and in the
 * e-mails sent with the Program, (ii) retain all hypertext links between
 * LinShare and linshare.org, between linagora.com and Linagora, and (iii)
 * refrain from infringing Linagora intellectual property rights over its
 * trademarks and commercial brands. Other Additional Terms apply, see
 * <http://www.linagora.com/licenses/> for more details.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License and
 * its applicable Additional Terms for LinShare along with this program. If not,
 * see <http://www.gnu.org/licenses/> for the GNU Affero General Public License
 * version 3 and <http://www.linagora.com/licenses/> for the Additional Terms
 * applicable to LinShare software.
 */
package org.linagora.linshare.core.facade.webservice.user.impl;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;

import org.linagora.linshare.core.domain.constants.FunctionalityNames;
import org.linagora.linshare.core.domain.entities.Functionality;
import org.linagora.linshare.core.domain.entities.User;
import org.linagora.linshare.core.exception.BusinessErrorCode;
import org.linagora.linshare.core.exception.BusinessException;
import org.linagora.linshare.core.facade.webservice.user.FunctionalityFacade;
import org.linagora.linshare.core.facade.webservice.user.dto.FunctionalityDto;
import org.linagora.linshare.core.service.AccountService;
import org.linagora.linshare.core.service.FunctionalityService;

import com.google.common.collect.Lists;

public class FunctionalityFacadeImpl extends UserGenericFacadeImp implements
		FunctionalityFacade {

	private FunctionalityService functionalityService;
	
	private List<String> excludes = new ArrayList<String>();

	public FunctionalityFacadeImpl(AccountService accountService,
			FunctionalityService functionalityService) {
		super(accountService);
		this.functionalityService = functionalityService;
		excludes.add(FunctionalityNames.SHARE_NOTIFICATION_BEFORE_EXPIRATION.toString());
		excludes.add(FunctionalityNames.UPLOAD_REQUEST__DELAY_BEFORE_NOTIFICATION.toString());
		excludes.add(FunctionalityNames.DOMAIN_MAIL.toString());
		excludes.add(FunctionalityNames.ANONYMOUS_URL.toString());
		excludes.add(FunctionalityNames.ANTIVIRUS.toString());
		excludes.add(FunctionalityNames.QUOTA_GLOBAL.toString());
		excludes.add(FunctionalityNames.QUOTA_USER.toString());
		excludes.add(FunctionalityNames.TIME_STAMPING.toString());
		excludes.add(FunctionalityNames.UPDATE_FILE.toString());
	}

	@Override
	public FunctionalityDto find(String identifier) throws BusinessException {
		User actor = checkAuthentication();
		Functionality functionality = functionalityService.getFunctionality(
				actor, actor.getDomainId(), identifier);
		if (excludes.contains(functionality.getIdentifier())) {
			throw new BusinessException(BusinessErrorCode.NO_SUCH_ELEMENT, "Functionality not found");
		}
		return functionality.toUserDto();
	}

	@Override
	public List<FunctionalityDto> findAll() throws BusinessException {
		User actor = checkAuthentication();
		List<FunctionalityDto> res = Lists.newArrayList();
		Set<Functionality> functionalities = functionalityService
				.getAllFunctionalities(actor, actor.getDomain());
		for (Functionality functionality : functionalities) {
			if (!excludes.contains(functionality.getIdentifier())) {
				res.add(functionality.toUserDto());
			}
		}
		return res;
	}

}

==> linshare-core-1.9.2-src.tar.bz2: src/main/java/org/linagora/linshare/core/facade/webservice/user/impl/FunctionalityFacadeImpl.java <==
/*
 * LinShare is an open source filesharing software, part of the LinPKI software
 * suite, developed by Linagora.
 * 
 * Copyright (C) 2015 LINAGORA
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version, provided you comply with the Additional Terms applicable for
 * LinShare software by Linagora pursuant to Section 7 of the GNU Affero General
 * Public License, subsections (b), (c), and (e), pursuant to which you must
 * notably (i) retain the display of the “LinShare™” trademark/logo at the top
 * of the interface window, the display of the “You are using the Open Source
 * and free version of LinShare™, powered by Linagora © 2009–2015. Contribute to
 * Linshare R&D by subscribing to an Enterprise offer!” infobox and in the
 * e-mails sent with the Program, (ii) retain all hypertext links between
 * LinShare and linshare.org, between linagora.com and Linagora, and (iii)
 * refrain from infringing Linagora intellectual property rights over its
 * trademarks and commercial brands. Other Additional Terms apply, see
 * <http://www.linagora.com/licenses/> for more details.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License and
 * its applicable Additional Terms for LinShare along with this program. If not,
 * see <http://www.gnu.org/licenses/> for the GNU Affero General Public License
 * version 3 and <http://www.linagora.com/licenses/> for the Additional Terms
 * applicable to LinShare software.
 */
package org.linagora.linshare.core.facade.webservice.user.impl;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;

import org.linagora.linshare.core.domain.constants.FunctionalityNames;
import org.linagora.linshare.core.domain.entities.Functionality;
import org.linagora.linshare.core.domain.entities.User;
import org.linagora.linshare.core.exception.BusinessErrorCode;
import org.linagora.linshare.core.exception.BusinessException;
import org.linagora.linshare.core.facade.webservice.user.FunctionalityFacade;
import org.linagora.linshare.core.facade.webservice.user.dto.FunctionalityDto;
import org.linagora.linshare.core.service.AccountService;
import org.linagora.linshare.core.service.FunctionalityService;

import com.google.common.collect.Lists;

public class FunctionalityFacadeImpl extends UserGenericFacadeImp implements
		FunctionalityFacade {

	private FunctionalityService functionalityService;
	
	private List<String> excludes = new ArrayList<String>();

	public FunctionalityFacadeImpl(AccountService accountService,
			FunctionalityService functionalityService) {
		super(accountService);
		this.functionalityService = functionalityService;
		excludes.add(FunctionalityNames.SHARE_NOTIFICATION_BEFORE_EXPIRATION.toString());
		excludes.add(FunctionalityNames.UPLOAD_REQUEST__DELAY_BEFORE_NOTIFICATION.toString());
		excludes.add(FunctionalityNames.DOMAIN__MAIL.toString());
		excludes.add(FunctionalityNames.ANONYMOUS_URL.toString());
		excludes.add(FunctionalityNames.ANTIVIRUS.toString());
		excludes.add(FunctionalityNames.QUOTA_GLOBAL.toString());
		excludes.add(FunctionalityNames.QUOTA_USER.toString());
		excludes.add(FunctionalityNames.TIME_STAMPING.toString());
		excludes.add(FunctionalityNames.UPDATE_FILE.toString());
	}

	@Override
	public FunctionalityDto find(String identifier) throws BusinessException {
		User actor = checkAuthentication();
		Functionality functionality = functionalityService.find(
				actor, actor.getDomainId(), identifier);
		if (excludes.contains(functionality.getIdentifier())) {
			throw new BusinessException(BusinessErrorCode.NO_SUCH_ELEMENT, "Functionality not found");
		}
		return functionality.toUserDto();
	}

	@Override
	public List<FunctionalityDto> findAll() throws BusinessException {
		User actor = checkAuthentication();
		List<FunctionalityDto> res = Lists.newArrayList();
		Set<Functionality> functionalities = functionalityService
				.findAll(actor, actor.getDomain());
		for (Functionality functionality : functionalities) {
			if (!excludes.contains(functionality.getIdentifier())) {
				res.add(functionality.toUserDto());
			}
		}
		return res;
	}

}
